diff --git a/ILSpy/Properties/app.config.template b/ILSpy/Properties/app.config.template
index 1a68767cc..6922fed23 100644
--- a/ILSpy/Properties/app.config.template
+++ b/ILSpy/Properties/app.config.template
@@ -4,8 +4,7 @@
-
-
+
diff --git a/ILSpy/app.manifest b/ILSpy/app.manifest
index dc49849b8..f9ecc04dd 100644
--- a/ILSpy/app.manifest
+++ b/ILSpy/app.manifest
@@ -52,6 +52,9 @@
true
+
+
+ true
diff --git a/ICSharpCode.Decompiler/CSharp/WholeProjectDecompiler.cs b/ICSharpCode.Decompiler/CSharp/WholeProjectDecompiler.cs
index 6444def9f..6261a283e 100644
--- a/ICSharpCode.Decompiler/CSharp/WholeProjectDecompiler.cs
+++ b/ICSharpCode.Decompiler/CSharp/WholeProjectDecompiler.cs
@@ -463,8 +463,8 @@ namespace ICSharpCode.Decompiler.CSharp
b.Append('.'); // allow dot, but never two in a row
else
b.Append('-');
- if (b.Length >= 64)
- break; // limit to 64 chars
+ if (b.Length >= 200)
+ break; // limit to 200 chars
}
if (b.Length == 0)
b.Append('-');